filter_operator — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# filter_operator

class `camelot.view.controls.filter_operator.` `FilterOperator`(entity, field_name, field_attributes, parent)

  Widget that allows applying various filter operators on a field

  `combobox_changed`(index)

    Whenever the combobox changes, show or hide the appropriate editors and emit the filter_changed signal

  `decorate_query`(query)

    Parameters: | query – an sqlalchemy query
    Returns: | the input query transformed to take into account the filter of

    this widget

  `editor_editing_finished`()

    Whenever one of the editors their value changes, emit the filters changed signal

  `get_operator_and_arity`()

    Returns: | the current operator and its arity

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus